# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['rfmix_reader']

package_data = \
{'': ['*']}

install_requires = \
['dask>=2024.5,<2025.0',
 'numpy>=1.26,<2.0',
 'pandas>=2.0,<3.0',
 'tqdm>=4.66,<5.0']

setup_kwargs = {
    'name': 'rfmix-reader',
    'version': '0.1.6',
    'description': 'RFMix-reader is a Python package designed to efficiently read and process output files generated by RFMix, a popular tool for estimating local ancestry in admixed populations. The package employs a lazy loading approach, which minimizes memory consumption by reading only the loci that are accessed by the user, rather than loading the entire dataset into memory at once.',
    'long_description': '# rfmix-reader\n`rfmix-reader` is a Python package designed to efficiently read and process output \nfiles generated by RFMix, a popular tool for estimating local ancestry in admixed \npopulations. The package employs a lazy loading approach, which minimizes memory \nconsumption by reading only the loci that are accessed by the user, rather than \nloading the entire dataset into memory at once. Additionally, we leverage GPU\nacceleration to improve computational speed.\n\n## Install\n`rfmix-reader` can be installed using [pip](https://pypi.python.org/pypi/pip):\n\n```bash\npip install rfmix-reader\n```\n\n**GPU Acceleration:**\n`rfmix-reader` leverages GPU acceleration for improved performance. To use this\nfunctionality, you will need to install the following libraries for your specific\nCUDA version:\n- `RAPIDS`: Refer to official installation guide [here](https://docs.rapids.ai/install)\n- `PyTorch`: Installation instructions can be found [here](https://pytorch.org/)\n\n**Additoinal Notes:** \n- We have not tested installation with `Docker` or `Conda` environemnts. Compatibility may vary.\n- If you do not have GPU, you can still use the basic functionality of `rfmix-reader`.\n\n\n## Key Features\n\n**Lazy Loading**\n- Reads data on-the-fly as requested, reducing memory footprint.\n- Ideal for working with large RFMix output files that may not fit entirely in memory.\n\n**Efficient Data Access**\n- Provides convenient access to specific loci or regions of interest.\n- Allows for selective loading of data, enabling faster processing times.\n\n**Seamless Integration**\n- Designed to work seamlessly with existing Python data analysis workflows.\n- Facilitates downstream analysis and manipulation of RFMix output data.\n\nWhether you\'re working with large-scale genomic datasets or have limited \ncomputational resources, RFMix-reader offers an efficient and memory-conscious \nsolution for reading and processing RFMix output files. Its lazy loading approach \nensures optimal resource utilization, making it a valuable tool for researchers \nand bioinformaticians working with admixed population data.\n\n## Usage\nThis works similarly to [`pandas-plink`]():\n\n```python\nfrom rfmix_reader import read_rfmix\n\nfile_path = "examples/two_popuations/"\nloci, rf_q, admix = read_rfmix(file_path)\n```\n\n## Authors\n* [Kynon JM Benjamin](https://github.com/Krotosbenjamin)\n\n## Citation\n\nPlease cite: XXXX.\n',
    'author': 'Kynon JM Benjamin',
    'author_email': 'heartgen.lab@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}
from build import *
build(setup_kwargs)

setup(**setup_kwargs)
